@@ -1,4 +1,4 @@
-# $Id: Master.pm,v 1.44 2006/08/20 15:10:05 joern Exp $
+# $Id: Master.pm,v 1.45 2006/08/25 16:20:21 joern Exp $
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2006 Jrn Reder <joern AT zyn.de>.
 # All Rights Reserved. See file COPYRIGHT for details.
@@ -834,4 +834,37 @@ sub get_job_from_id {
     return $self->scheduler->get_jobs_by_id->{$job_id};
 }
 
+sub reset_job {
+    my $self = shift;
+    my ($job_id) = @_;
+    my $job = $self->get_job_from_id($job_id);
+    
+    my $old_state = $job->get_state;
+    
+    $job->set_state("waiting");
+    $job->set_progress_start_time();
+    $job->set_progress_end_time();
+    $job->set_cancelled();
+    $job->set_error_message();
+    $job->set_last_percent_logged(0);
+    $job->set_last_progress();
+    $job->set_progress_cnt(0);
+
+    if ( $old_state ne 'waiting' ) {
+        my $group = $job->get_group;
+        while ( $group ) {
+print "Group: ".$group->get_title."\n";
+            $group->set_progress_cnt($group->get_progress_cnt - 1);
+            $group->set_state("waiting");
+            $group = $group->get_group;
+        }
+    }
+
+    my $project = $self->scheduler->get_projects_by_job_id->{$job_id};
+    $project->set_state("not scheduled");
+    $project->save;
+
+    1;
+}
+
 1;
